ReturningClauseHelper

Trait ReturningClauseHelper 

pub trait ReturningClauseHelper<S> {
    type WithReturning;
}
Available on crate feature i-implement-a-third-party-backend-and-opt-into-breaking-changes only.
Helper trait that maps an INSERT/UPDATE/DELETE statement type to the same statement type with an explicit ReturningClause<S> attached.

This is used to spell the return type of .returning(...) in the dsl module without naming each individual statement type.

Required Associated Types

type WithReturning

Self with a RETURNING S clause attached.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors