pub struct OldIdent;Available on crate feature
i-implement-a-third-party-backend-and-opt-into-breaking-changes only.Expand description
Represents the identifier old or old_value in the RETURNING clause.
It is independent of the table of the column, and used as QS in marker in AppearsInFromClause.
We use this to typecheck that there is only one old or old_value identifier when we use old or old_value, so that
there is no ambiguity, and also as a generic
“any valid OLD statement-kind marker for ReturningQuerySource”.